@@ -1,3 +1,3 @@
-from dataset.loader import Loader
+from data.loader import Loader
 from img.augmentation import ImageTransformer
 from img.constants import *
